@@ -12,9 +12,9 @@ import re
 import sys
 from collections import namedtuple
 
-SERIES = 'latentcall'
+SERIES = 'windowlicker'
 
-__version__ = '4.1.0'
+__version__ = '4.2.2'
 __author__ = 'Ask Solem'
 __contact__ = 'ask@celeryproject.org'
 __homepage__ = 'http://celeryproject.org'
@@ -23,12 +23,12 @@ __keywords__ = 'task job queue distributed messaging actor'
 
 # -eof meta-
 
-__all__ = [
+__all__ = (
     'Celery', 'bugreport', 'shared_task', 'task',
     'current_app', 'current_task', 'maybe_signature',
     'chain', 'chord', 'chunks', 'group', 'signature',
     'xmap', 'xstarmap', 'uuid',
-]
+)
 
 VERSION_BANNER = '{0} ({1})'.format(__version__, SERIES)
 
@@ -145,6 +145,7 @@ def maybe_patch_concurrency(argv=sys.argv,
         from celery import concurrency
         concurrency.get_implementation(pool)
 
+
 # Lazy loading
 from . import local  # noqa
 
